@@ -1,6 +1,6 @@
 import numpy as np
 import pandas as pd
-from fbprophet import Prophet
+from prophet import Prophet
 from sparkles.fbprophet_hacks import suppress_stdout_stderr
 
 # declare variables for testing
@@ -29,7 +29,7 @@ def decompose_sales(sales_data: pd.DataFrame):
     forecast_reduced = forecast.loc[:, ["ds", "yearly", "weekly"]]
     forecast_reduced["dow"] = forecast_reduced.ds.dt.weekday
     forecast_reduced["doy"] = forecast_reduced.ds.dt.dayofyear
-    forecast_reduced["woy"] = forecast_reduced.ds.dt.week
+    forecast_reduced["woy"] = forecast_reduced.ds.dt.isocalendar().week
 
     weekly_seasonality = forecast_reduced.groupby("dow")["weekly"].mean() + 1
 
