@@ -3,7 +3,7 @@ from typing import List
 
 import numpy as np
 import pandas as pd
-from fbprophet import Prophet
+from prophet import Prophet
 from sparkles import trunc_date
 from sparkles.fbprophet_hacks import suppress_stdout_stderr
 
@@ -151,7 +151,7 @@ def forecast_far(
     future.rename(columns={0: "ds"}, inplace=True)
 
     future["dow"] = future.ds.dt.weekday  # future.ds.dt.dayofweek
-    future["woy"] = future.ds.dt.week
+    future["woy"] = future.ds.dt.isocalendar().week
 
     output = pd.merge(
         future, predictions, left_on=["woy", "dow"], right_on=["woy", "dow"]
