@@ -761,3 +761,57 @@ def sales_little_data():
     df.ds = pd.to_datetime(df.ds)
 
     return df
+
+
+@pytest.fixture(scope="module")
+def sales_week_data():
+    df = pd.DataFrame(
+        data=[
+            ["2020-07-01", 25],
+            ["2020-07-02", 50],
+            ["2020-07-03", 75],
+            ["2020-07-04", 50],
+            ["2020-07-05", 25],
+            ["2020-07-06", 50],
+            ["2020-07-07", 75],
+        ],
+        columns=["ds", "y"],
+    )
+
+    df.ds = pd.to_datetime(df.ds)
+
+    return df
+
+
+@pytest.fixture(scope="module")
+def sales_three_week_data():
+    df = pd.DataFrame(
+        data=[
+            ["2020-07-01", 25],
+            ["2020-07-02", 50],
+            ["2020-07-03", 75],
+            ["2020-07-04", 50],
+            ["2020-07-05", 25],
+            ["2020-07-06", 50],
+            ["2020-07-07", 75],
+            ["2020-07-09", 25],
+            ["2020-07-10", 50],
+            ["2020-07-11", 75],
+            ["2020-07-12", 50],
+            ["2020-07-13", 25],
+            ["2020-07-14", 50],
+            ["2020-07-15", 75],
+            ["2020-07-16", 25],
+            ["2020-07-17", 50],
+            ["2020-07-18", 75],
+            ["2020-07-19", 50],
+            ["2020-07-20", 25],
+            ["2020-07-21", 50],
+            ["2020-07-22", 75],
+        ],
+        columns=["ds", "y"],
+    )
+
+    df.ds = pd.to_datetime(df.ds)
+
+    return df
