@@ -1,11 +1,9 @@
 import numpy as np
 import pandas as pd
 
-from tank_forecaster import forecaster_advanced
-from tank_forecaster.decomp import (
-    generic_weekly_seasonality,
-    generic_yearly_seasonality,
-)
+from tank_forecaster import forecaster
+from tank_forecaster.decomp import (generic_weekly_seasonality,
+                                    generic_yearly_seasonality)
 
 
 def is_a_valid_forecast_dataframe(df):
@@ -20,7 +18,7 @@ def is_a_valid_forecast_dataframe(df):
 
 
 def test_far_returns_a_valid_dataframe():
-    x = forecaster_advanced.forecast_far(
+    x = forecaster.forecast_far(
         daily_lift_est=5000,
         yearly_seasonality=generic_yearly_seasonality,
         weekly_seasonality=generic_weekly_seasonality,
@@ -29,7 +27,7 @@ def test_far_returns_a_valid_dataframe():
 
 
 def test_far_start_date_works():
-    x = forecaster_advanced.forecast_far(
+    x = forecaster.forecast_far(
         daily_lift_est=5000,
         yearly_seasonality=generic_yearly_seasonality,
         weekly_seasonality=generic_weekly_seasonality,
